PiGlow
======

Library for the Pimoroni Pibrella board, based on the sn3218 IC https://github.com/Gadgetoid/python-sn3218

I have attempted to make this library code compatible with Jason (@Boeeerb) Barnett's PiGlow examples,
he maintains by far the most complete codebase and documentation for the PiGlow here: https://github.com/Boeeerb/PiGlow




